==> vtk6-6.3.0-4-armv6h.pkg.tar.xz: vtk/vtkExodusIIWriter.java <==
// java wrapper for vtkExodusIIWriter object
//

package vtk;
import vtk.*;

public class vtkExodusIIWriter extends vtkWriter
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetModelMetadata_2(vtkModelMetadata id0);
  public void SetModelMetadata(vtkModelMetadata id0)
    { SetModelMetadata_2(id0); }

  private native long GetModelMetadata_3();
  public vtkModelMetadata GetModelMetadata() {
    long temp = GetModelMetadata_3();

    if (temp == 0) return null;
    return (vtkModelMetadata)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void SetFileName_4(String id0);
  public void SetFileName(String id0)
    { SetFileName_4(id0); }

  private native String GetFileName_5();
  public String GetFileName()
    { return GetFileName_5(); }

  private native void SetStoreDoubles_6(int id0);
  public void SetStoreDoubles(int id0)
    { SetStoreDoubles_6(id0); }

  private native int GetStoreDoubles_7();
  public int GetStoreDoubles()
    { return GetStoreDoubles_7(); }

  private native void SetGhostLevel_8(int id0);
  public void SetGhostLevel(int id0)
    { SetGhostLevel_8(id0); }

  private native int GetGhostLevel_9();
  public int GetGhostLevel()
    { return GetGhostLevel_9(); }

  private native void SetWriteOutBlockIdArray_10(int id0);
  public void SetWriteOutBlockIdArray(int id0)
    { SetWriteOutBlockIdArray_10(id0); }

  private native int GetWriteOutBlockIdArray_11();
  public int GetWriteOutBlockIdArray()
    { return GetWriteOutBlockIdArray_11(); }

  private native void WriteOutBlockIdArrayOn_12();
  public void WriteOutBlockIdArrayOn()
    { WriteOutBlockIdArrayOn_12(); }

  private native void WriteOutBlockIdArrayOff_13();
  public void WriteOutBlockIdArrayOff()
    { WriteOutBlockIdArrayOff_13(); }

  private native void SetWriteOutGlobalNodeIdArray_14(int id0);
  public void SetWriteOutGlobalNodeIdArray(int id0)
    { SetWriteOutGlobalNodeIdArray_14(id0); }

  private native int GetWriteOutGlobalNodeIdArray_15();
  public int GetWriteOutGlobalNodeIdArray()
    { return GetWriteOutGlobalNodeIdArray_15(); }

  private native void WriteOutGlobalNodeIdArrayOn_16();
  public void WriteOutGlobalNodeIdArrayOn()
    { WriteOutGlobalNodeIdArrayOn_16(); }

  private native void WriteOutGlobalNodeIdArrayOff_17();
  public void WriteOutGlobalNodeIdArrayOff()
    { WriteOutGlobalNodeIdArrayOff_17(); }

  private native void SetWriteOutGlobalElementIdArray_18(int id0);
  public void SetWriteOutGlobalElementIdArray(int id0)
    { SetWriteOutGlobalElementIdArray_18(id0); }

  private native int GetWriteOutGlobalElementIdArray_19();
  public int GetWriteOutGlobalElementIdArray()
    { return GetWriteOutGlobalElementIdArray_19(); }

  private native void WriteOutGlobalElementIdArrayOn_20();
  public void WriteOutGlobalElementIdArrayOn()
    { WriteOutGlobalElementIdArrayOn_20(); }

  private native void WriteOutGlobalElementIdArrayOff_21();
  public void WriteOutGlobalElementIdArrayOff()
    { WriteOutGlobalElementIdArrayOff_21(); }

  private native void SetWriteAllTimeSteps_22(int id0);
  public void SetWriteAllTimeSteps(int id0)
    { SetWriteAllTimeSteps_22(id0); }

  private native int GetWriteAllTimeSteps_23();
  public int GetWriteAllTimeSteps()
    { return GetWriteAllTimeSteps_23(); }

  private native void WriteAllTimeStepsOn_24();
  public void WriteAllTimeStepsOn()
    { WriteAllTimeStepsOn_24(); }

  private native void WriteAllTimeStepsOff_25();
  public void WriteAllTimeStepsOff()
    { WriteAllTimeStepsOff_25(); }

  private native void SetBlockIdArrayName_26(String id0);
  public void SetBlockIdArrayName(String id0)
    { SetBlockIdArrayName_26(id0); }

  private native String GetBlockIdArrayName_27();
  public String GetBlockIdArrayName()
    { return GetBlockIdArrayName_27(); }

  public vtkExodusIIWriter() { super(); }

  public vtkExodusIIWriter(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.1.0-6-armv6h.pkg.tar.xz: vtk/vtkExodusIIWriter.java <==
// java wrapper for vtkExodusIIWriter object
//

package vtk;
import vtk.*;

public class vtkExodusIIWriter extends vtkWriter
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetModelMetadata_2(vtkModelMetadata id0);
  public void SetModelMetadata(vtkModelMetadata id0)
    { SetModelMetadata_2(id0); }

  private native long GetModelMetadata_3();
  public vtkModelMetadata GetModelMetadata() {
    long temp = GetModelMetadata_3();

    if (temp == 0) return null;
    return (vtkModelMetadata)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetFileName_4(String id0);
  public void SetFileName(String id0)
    { SetFileName_4(id0); }

  private native String GetFileName_5();
  public String GetFileName()
    { return GetFileName_5(); }

  private native void SetStoreDoubles_6(int id0);
  public void SetStoreDoubles(int id0)
    { SetStoreDoubles_6(id0); }

  private native int GetStoreDoubles_7();
  public int GetStoreDoubles()
    { return GetStoreDoubles_7(); }

  private native void SetGhostLevel_8(int id0);
  public void SetGhostLevel(int id0)
    { SetGhostLevel_8(id0); }

  private native int GetGhostLevel_9();
  public int GetGhostLevel()
    { return GetGhostLevel_9(); }

  private native void SetWriteOutBlockIdArray_10(int id0);
  public void SetWriteOutBlockIdArray(int id0)
    { SetWriteOutBlockIdArray_10(id0); }

  private native int GetWriteOutBlockIdArray_11();
  public int GetWriteOutBlockIdArray()
    { return GetWriteOutBlockIdArray_11(); }

  private native void WriteOutBlockIdArrayOn_12();
  public void WriteOutBlockIdArrayOn()
    { WriteOutBlockIdArrayOn_12(); }

  private native void WriteOutBlockIdArrayOff_13();
  public void WriteOutBlockIdArrayOff()
    { WriteOutBlockIdArrayOff_13(); }

  private native void SetWriteOutGlobalNodeIdArray_14(int id0);
  public void SetWriteOutGlobalNodeIdArray(int id0)
    { SetWriteOutGlobalNodeIdArray_14(id0); }

  private native int GetWriteOutGlobalNodeIdArray_15();
  public int GetWriteOutGlobalNodeIdArray()
    { return GetWriteOutGlobalNodeIdArray_15(); }

  private native void WriteOutGlobalNodeIdArrayOn_16();
  public void WriteOutGlobalNodeIdArrayOn()
    { WriteOutGlobalNodeIdArrayOn_16(); }

  private native void WriteOutGlobalNodeIdArrayOff_17();
  public void WriteOutGlobalNodeIdArrayOff()
    { WriteOutGlobalNodeIdArrayOff_17(); }

  private native void SetWriteOutGlobalElementIdArray_18(int id0);
  public void SetWriteOutGlobalElementIdArray(int id0)
    { SetWriteOutGlobalElementIdArray_18(id0); }

  private native int GetWriteOutGlobalElementIdArray_19();
  public int GetWriteOutGlobalElementIdArray()
    { return GetWriteOutGlobalElementIdArray_19(); }

  private native void WriteOutGlobalElementIdArrayOn_20();
  public void WriteOutGlobalElementIdArrayOn()
    { WriteOutGlobalElementIdArrayOn_20(); }

  private native void WriteOutGlobalElementIdArrayOff_21();
  public void WriteOutGlobalElementIdArrayOff()
    { WriteOutGlobalElementIdArrayOff_21(); }

  private native void SetWriteAllTimeSteps_22(int id0);
  public void SetWriteAllTimeSteps(int id0)
    { SetWriteAllTimeSteps_22(id0); }

  private native int GetWriteAllTimeSteps_23();
  public int GetWriteAllTimeSteps()
    { return GetWriteAllTimeSteps_23(); }

  private native void WriteAllTimeStepsOn_24();
  public void WriteAllTimeStepsOn()
    { WriteAllTimeStepsOn_24(); }

  private native void WriteAllTimeStepsOff_25();
  public void WriteAllTimeStepsOff()
    { WriteAllTimeStepsOff_25(); }

  private native void SetBlockIdArrayName_26(String id0);
  public void SetBlockIdArrayName(String id0)
    { SetBlockIdArrayName_26(id0); }

  private native String GetBlockIdArrayName_27();
  public String GetBlockIdArrayName()
    { return GetBlockIdArrayName_27(); }

  private native void SetIgnoreMetaDataWarning_28(boolean id0);
  public void SetIgnoreMetaDataWarning(boolean id0)
    { SetIgnoreMetaDataWarning_28(id0); }

  private native boolean GetIgnoreMetaDataWarning_29();
  public boolean GetIgnoreMetaDataWarning()
    { return GetIgnoreMetaDataWarning_29(); }

  private native void IgnoreMetaDataWarningOn_30();
  public void IgnoreMetaDataWarningOn()
    { IgnoreMetaDataWarningOn_30(); }

  private native void IgnoreMetaDataWarningOff_31();
  public void IgnoreMetaDataWarningOff()
    { IgnoreMetaDataWarningOff_31(); }

  public vtkExodusIIWriter() { super(); }

  public vtkExodusIIWriter(long id) { super(id); }
  public native long   VTKInit();

}
